documentationtools.APICrawler
=============================

.. abjad-lineage:: abjad.tools.documentationtools.APICrawler.APICrawler.APICrawler

.. autoclass:: abjad.tools.documentationtools.APICrawler.APICrawler.APICrawler
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.documentationtools.APICrawler.APICrawler.APICrawler.code_root
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.APICrawler.APICrawler.APICrawler.docs_root
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.APICrawler.APICrawler.APICrawler.module_crawler
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.APICrawler.APICrawler.APICrawler.prefix
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.APICrawler.APICrawler.APICrawler.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.documentationtools.APICrawler.APICrawler.APICrawler.__call__
   :noindex:

.. automethod:: abjad.tools.documentationtools.APICrawler.APICrawler.APICrawler.__eq__
   :noindex:

.. automethod:: abjad.tools.documentationtools.APICrawler.APICrawler.APICrawler.__ge__
   :noindex:

.. automethod:: abjad.tools.documentationtools.APICrawler.APICrawler.APICrawler.__gt__
   :noindex:

.. automethod:: abjad.tools.documentationtools.APICrawler.APICrawler.APICrawler.__le__
   :noindex:

.. automethod:: abjad.tools.documentationtools.APICrawler.APICrawler.APICrawler.__lt__
   :noindex:

.. automethod:: abjad.tools.documentationtools.APICrawler.APICrawler.APICrawler.__ne__
   :noindex:

.. automethod:: abjad.tools.documentationtools.APICrawler.APICrawler.APICrawler.__repr__
   :noindex:
